# TODO: This package wants homology, if the Pascal issues can be resolved:
# http://ljk.imag.fr/membres/Jean-Guillaume.Dumas/Homology/
# TODO: If the Singular package gets a usable license, this package wants it.

%global pkgname hap

Name:           gap-pkg-%{pkgname}
Version:        1.19
Release:        1%{?dist}
Summary:        Homological Algebra Programming for GAP
BuildArch:      noarch

%global majver %(cut -d. -f1-2 <<< %{version})

License:        GPLv2+
URL:            http://hamilton.nuigalway.ie/Hap/www/
Source0:        http://hamilton.nuigalway.ie/Hap/%{pkgname}%{majver}.tar.gz
# Fix documentation bugs
Patch0:         %{name}-doc.patch
# Adapt to the removal of DIMS from polymake.  See gap-pkg-polymaking.
Patch1:         %{name}-dims.patch
# Change from the old nql package name to the new lpres name
Patch2:         %{name}-lpres.patch

BuildRequires:  asymptote
BuildRequires:  gap-devel
BuildRequires:  GAPDoc-latex
BuildRequires:  gap-pkg-aclib
BuildRequires:  gap-pkg-congruence
BuildRequires:  gap-pkg-crystcat
BuildRequires:  gap-pkg-edim
BuildRequires:  gap-pkg-fga
BuildRequires:  gap-pkg-lpres
BuildRequires:  gap-pkg-nq
BuildRequires:  gap-pkg-polycyclic
BuildRequires:  gap-pkg-polymaking
BuildRequires:  graphviz
BuildRequires:  ImageMagick
BuildRequires:  perl-interpreter
BuildRequires:  vim-minimal
BuildRequires:  xdg-utils

Requires:       coreutils
Requires:       gap-core
Requires:       gap-pkg-aclib
Requires:       gap-pkg-crystcat
Requires:       gap-pkg-fga
Requires:       gap-pkg-polycyclic
Requires:       xdg-utils

Recommends:     gap-pkg-congruence
Recommends:     gap-pkg-edim
Recommends:     gap-pkg-lpres
Recommends:     gap-pkg-nq
Recommends:     gap-pkg-polymaking

Suggests:       asymptote
Suggests:       gap-pkg-hapcryst
Suggests:       gap-pkg-xmod
Suggests:       graphviz
Suggests:       ImageMagick
Suggests:       openssh-clients

%description
HAP is a homological algebra library for use with the GAP computer
algebra system, and is still under development.  Its initial focus is on
computations related to the cohomology of groups.  Both finite and
infinite groups are handled, with emphasis on integral coefficients.

Recent additions include some functions for computing homology of
crossed modules and simplicial groups, and also some functions for
handling simplicial complexes, cubical complexes and regular
CW-complexes in the context of topological data analysis.

%package doc
Summary:        HAP documentation
Requires:       %{name} = %{version}-%{release}
Requires:       gap-online-help

%description doc
This package contains documentation for gap-pkg-%{pkgname}.

%prep
%autosetup -p0 -n Hap%{majver}

fixtimestamp() {
  touch -r $1.orig $1
  rm -f $1.orig
}

# Change the path to the perl executable
sed -i.orig 's,/usr/local/bin/perl,%{_bindir}/perl,' lib/PolyComplexes/prog
fixtimestamp lib/PolyComplexes/prog

# Don't force the web browser to be firefox
sed -i.orig 's/"firefox"/"xdg-open"/' lib/externalSoftware.gap
fixtimestamp lib/externalSoftware.gap

# Replace glacially slow vi scripts with speedy sed scripts
cat << EOF > lib/TitlePage/vis
#!/usr/bin/sh
if [ $# -gt 0 ]; then
  sed -e 's,<Item>,<Br/>,g' \\
      -e 's,<Row>,<Br/>,g' \\
      -e 's,</Item>,<Br/>,g' \\
      -e 's,</Row>,<Br/>,g' \\
      -e 's,<Table Align="|l|" >,<Br/>,g' \\
      -e 's,</Table>,<Br/>,g' \\
      -e 's,<List>,<Br/>,g' \\
      -e 's,</List>,<Br/>,g' \\
      -e 's,</C>,&<Br/>,g' \\
      -e 's,</Index>,&::::::::::::::::::::::::<Br/>,g' \\
      -i $@
fi
EOF
cat << EOF > lib/TitlePage/viscript
#!/usr/bin/sh
if [ $# -gt 0 ]; then
  sed -e 's,<h3>Contents</h3>,<h2>HAP Functions</h2>,g' \
      -e 's,<p><code,<code,g' \
      -e 's,code></p>,code>,g' \
      -e '16d' \
      -e 's,<body>,&<a href="../www/index.html"><small>HAP home</small></a>,' \
      -e 's,<table,& cellspacing="10",' \
      -i $@
fi
EOF

# Remove obsolete files
find . -name \*keep\* | xargs rm -f
find . -name \*working\* | xargs rm -f
rm -fr lib/*/*old* www/SideLinks/About/*OLD*
rm -f lib/Functors/*.ancient lib/GOuterGroups/*.trial

# Clean up documentation to force complete rebuild
rm -fr pdfdoc/*
rm -f doc/*.{aux,bbl,blg,dvi,html,idx,ilg,ind,log,out,pdf,pnr,six,tex,toc,txt}

# Update obsolete documentation constructs
for fil in doc/*.xml doc/newman/*.xml; do
  sed -i.orig 's/|l|/|p{\\textwidth}|/;s,<Verb>\(.*\)</Verb>,<C>\1</C>,' $fil
  fixtimestamp $fil
done

# Fix end of line encoding
sed -i.orig 's/\r//' doc/manual.css
fixtimestamp doc/manual.css

# Nearly every file has the executable bit on.  Turn them all off, then restore
# the handful where that is actually correct.
find -O3 . -type f -perm /0111 | xargs chmod a-x
chmod a+x compile* uncompile* doc/newman/{llaregub,xmltex} \
      lib/PolyComplexes/prog lib/TitlePage/vis*

%build
# Build the documentation
export LC_ALL=C.UTF-8
mkdir ../pkg
ln -s ../Hap%{majver} ../pkg
# TODO: If we ever get Singular support working, also call MakeHAPprimeDoc().
gap -l "$PWD/..;%{_gap_dir}" << EOF
LoadPackage( "Hap" );
MakeHAPManual();
EOF
rm -fr ../pkg

%install
mkdir -p %{buildroot}%{_gap_dir}/pkg
cp -a ../Hap%{majver} %{buildroot}%{_gap_dir}/pkg/Hap
chmod a-x %{buildroot}%{_gap_dir}/pkg/Hap/doc/newman/{llaregub,xmltex}
rm -f %{buildroot}%{_gap_dir}/pkg/Hap/{compile*,README.HAP,uncompile*}
rm -f %{buildroot}%{_gap_dir}/pkg/Hap/doc/.{idl.ilg,idl.ind,ind,tex}
rm -fr %{buildroot}%{_gap_dir}/pkg/Hap/lib/CompiledGAP
find %{buildroot}%{_gap_dir}/pkg/Hap -name .\*swp -exec rm {} +

%check
# Expect "unbound global variable" warnings because we have neither the GAP
# singular package nor the GAP homology package in Fedora.
export LC_ALL=C.UTF-8
cd test
gap -l "%{buildroot}%{_gap_dir};%{_gap_dir}" << EOF
LoadPackage("hap");
GAP_EXIT_CODE(Test("hap.tst", rec( compareFunction := "uptowhitespace" )));
EOF

%files
%doc README.HAP
%license www/copyright/*.html
%{_gap_dir}/pkg/Hap/
%exclude %{_gap_dir}/pkg/Hap/doc/
%exclude %{_gap_dir}/pkg/Hap/pdfdoc/

%files doc
%docdir %{_gap_dir}/pkg/Hap/doc/
%docdir %{_gap_dir}/pkg/Hap/pdfdoc/
%{_gap_dir}/pkg/Hap/doc/
%{_gap_dir}/pkg/Hap/pdfdoc/

%changelog
* Wed Feb  6 2019 Jerry James <loganjerry@gmail.com> - 1.19-1
- New upstream release
- Add -dims and -lpres patches
- Add -doc subpackage

* Thu Jan 31 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1.12.5-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.12.5-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.12.5-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Sat Feb  3 2018 Jerry James <loganjerry@gmail.com> - 1.12.5-1
- New upstream release

* Wed Sep  6 2017 Jerry James <loganjerry@gmail.com> - 1.12.0-1
- New upstream release

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.11.14-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.11.14-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Tue Dec 13 2016 Jerry James <loganjerry@gmail.com> - 1.11.14-1
- New upstream release
- Use upstream's 3-part version scheme
- Suggest the hapcryst and xmod packages

* Tue Aug 16 2016 Jerry James <loganjerry@gmail.com> - 1.11-2
- Switch crystcat from Recommends to Requires

* Fri Aug  5 2016 Jerry James <loganjerry@gmail.com> - 1.11-1
- Initial RPM
